@@ -1,10 +1,17 @@
+##
+# name:      Template::Toolkit::Simple
+# abstract:  A Simple Interface to Template Toolkit
+# author:    Ingy döt Net <ingy@cpan.org>
+# copyright: 2008, 2009, 2010, 2011
+# license:   perl
+
 package Template::Toolkit::Simple;
 use Template::Constants qw( :debug );
 use strict;
 use warnings;
 use 5.008003;
 
-our $VERSION = '0.12';
+our $VERSION = '0.13';
 
 use Template;
 use Getopt::Long;
@@ -247,10 +254,6 @@ sub _run_command {
 
 =encoding utf8
 
-=head1 NAME
-
-Template::Toolkit::Simple - A Simple Interface to Template Toolkit
-
 =head1 SYNOPSIS
 
     use Template::Toolkit::Simple;
@@ -288,7 +291,7 @@ an error occurs, it is printed to STDERR.
 
     tt-render [template-options] file-name
 
-=head1 TEMPLATE NAME
+=head1 TEMPLATE PATH
 
 When using Template::Toolkit::Simple or C<tt-render>, the most common
 parameters you will use are the main template file name and the
@@ -473,18 +476,3 @@ method returns the error message on a failure.
 =item encoding() -- Default is 'utf8'
 
 =back
-
-=head1 AUTHOR
-
-Ingy döt Net <ingy@cpan.org>
-
-=head1 COPYRIGHT
-
-Copyright (c) 2008, 2009, 2010, 2011. Ingy döt Net.
-
-This program is free software; you can redistribute it and/or modify it
-under the same terms as Perl itself.
-
-See http://www.perl.com/perl/misc/Artistic.html
-
-=cut
